pub struct PublicKey { /* private fields */ }Expand description
Represents the public key of a Relay.
Public keys are based on ed25519 but this should be considered an implementation detail for now. We only ever represent public keys on the wire as opaque ascii encoded strings of arbitrary format or length.
Implementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn verify(
&self,
data: &[u8],
sig: SignatureRef<'_>,
start_time: DateTime<Utc>,
max_age: Duration,
) -> Result<VerifiedSignatureHeader, SignatureError>
pub fn verify( &self, data: &[u8], sig: SignatureRef<'_>, start_time: DateTime<Utc>, max_age: Duration, ) -> Result<VerifiedSignatureHeader, SignatureError>
Verifies the signature and returns the embedded signature header.
Returns SignatureError when the signature cannot be verified.
Sourcepub fn unpack<D: DeserializeOwned>(
&self,
data: &[u8],
signature: SignatureRef<'_>,
start_time: DateTime<Utc>,
max_age_diff: Duration,
) -> Result<D, UnpackError>
pub fn unpack<D: DeserializeOwned>( &self, data: &[u8], signature: SignatureRef<'_>, start_time: DateTime<Utc>, max_age_diff: Duration, ) -> Result<D, UnpackError>
Unpacks signed data and returns it with header.